@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -28,14 +28,8 @@ use utf8;
 use strict;
 use Gtk2;
 
-#Gettext and filename parsing
-use POSIX qw/setlocale strftime/;
-use Locale::gettext;
-
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -46,6 +40,13 @@ sub new {
 	#constructor
 	my $self = { _common => shift };
 
+	#import shutter dialogs
+	my $current_window = $self->{_common}->get_mainwindow;
+	$self->{_dialogs} = Shutter::App::SimpleDialogs->new( $current_window );
+
+	#gettext
+	$self->{_d} = $self->{_common}->get_gettext;
+
 	bless $self, $class;
 	return $self;
 }
@@ -53,19 +54,58 @@ sub new {
 sub xdg_open {
 	my ( $self, $dialog, $link, $user_data ) = @_;
 	system("xdg-open $link");
-	return TRUE;
+	if($?){
+		my $response = $self->{_dialogs}->dlg_error_message( 
+			sprintf( $self->{_d}->get("Error while executing %s."), "'xdg-open'"),
+			sprintf( $self->{_d}->get("There was an error executing %s."), "'xdg-open'"),		
+			undef, undef, undef,
+			undef, undef, undef,
+			sprintf( $self->{_d}->get("Exit Code: %d."), $? >> 8)
+		);
+	}		
 }
 
 sub xdg_open_mail {
 	my ( $self, $dialog, $mail, $user_data ) = @_;
 	system("xdg-email $mail $user_data");
-	return TRUE;
+	if($?){
+		my $response = $self->{_dialogs}->dlg_error_message( 
+			sprintf( $self->{_d}->get("Error while executing %s."), "'xdg-email'"),
+			sprintf( $self->{_d}->get("There was an error executing %s."), "'xdg-email'"),		
+			undef, undef, undef,
+			undef, undef, undef,
+			sprintf( $self->{_d}->get("Exit Code: %d."), $? >> 8)
+		);
+	}		
+}
+
+sub thunderbird_open {
+	my ( $self, $tcmd, $user_data ) = @_;
+	system("$tcmd $user_data");
+	#~ print "$tcmd $user_data\n";
+	if($?){
+		my $response = $self->{_dialogs}->dlg_error_message( 
+			sprintf( $self->{_d}->get("Error while executing %s."), "'" . $tcmd . "'"),
+			sprintf( $self->{_d}->get("There was an error executing %s."), "'" . $tcmd . "'"),
+			undef, undef, undef,
+			undef, undef, undef,
+			sprintf( $self->{_d}->get("Exit Code: %d."), $? >> 8)
+		);
+	}	
 }
 
 sub nautilus_sendto {
 	my ( $self, $user_data ) = @_;
 	system("nautilus-sendto $user_data &");
-	return TRUE;
+	if($?){
+		my $response = $self->{_dialogs}->dlg_error_message( 
+			sprintf( $self->{_d}->get("Error while executing %s."), "'nautilus-sendto'"),
+			sprintf( $self->{_d}->get("There was an error executing %s."), "'nautilus-sendto'"),		
+			undef, undef, undef,
+			undef, undef, undef,
+			sprintf( $self->{_d}->get("Exit Code: %d."), $? >> 8)
+		);
+	}	
 }
 
 sub file_exists {
@@ -76,6 +116,14 @@ sub file_exists {
 	return FALSE;
 }
 
+sub folder_exists {
+	my ( $self, $folder ) = @_;
+	return FALSE unless $folder;
+	$folder = $self->switch_home_in_file($folder);
+	return TRUE if ( -d $folder && -r $folder );
+	return FALSE;
+}
+
 sub uri_exists {
 	my ( $self, $filename ) = @_;
 	return FALSE unless $filename;
