@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -28,14 +28,8 @@ use utf8;
 use strict;
 use Gtk2;
 
-#Gettext and filename parsing
-use POSIX qw/setlocale strftime/;
-use Locale::gettext;
-
-#define constants
-#--------------------------------------
-use constant TRUE  => 1;
-use constant FALSE => 0;
+#Glib
+use Glib qw/TRUE FALSE/; 
 
 #--------------------------------------
 
@@ -110,7 +104,6 @@ sub fct_ret_file_menu {
 	$self->{_menu_file}     = Gtk2::Menu->new();
 
 	$self->{_menuitem_new} = Gtk2::ImageMenuItem->new_from_stock('gtk-new');
-	$self->{_menuitem_new}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>N'), qw/visible/ );
 	$self->{_menuitem_new}->set_submenu( $self->fct_ret_new_menu( $accel_group, $d, $shutter_root ) );
 	$self->{_menu_file}->append( $self->{_menuitem_new} );
 
@@ -132,6 +125,16 @@ sub fct_ret_file_menu {
 	$self->{_menuitem_save_as}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Control>S'), qw/visible/ );
 	$self->{_menu_file}->append( $self->{_menuitem_save_as} );
 
+	#~ $self->{_menuitem_export_svg} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Export to SVG...') );
+	#~ $self->{_menuitem_export_svg}->set_sensitive(FALSE);
+	#~ $self->{_menuitem_export_svg}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Alt>S'), qw/visible/ );
+	#~ $self->{_menu_file}->append( $self->{_menuitem_export_svg} );
+
+	$self->{_menuitem_export_pdf} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('E_xport to PDF...') );
+	$self->{_menuitem_export_pdf}->set_sensitive(FALSE);
+	$self->{_menuitem_export_pdf}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Alt>P'), qw/visible/ );
+	$self->{_menu_file}->append( $self->{_menuitem_export_pdf} );
+
 	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
 
 	#~ $self->{_menuitem_pagesetup} = Gtk2::ImageMenuItem->new_from_stock('gtk-page-setup');
@@ -152,7 +155,7 @@ sub fct_ret_file_menu {
 
 	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
 
-	$self->{_menuitem_email} = Gtk2::ImageMenuItem->new($d->get('Send by Email...'));
+	$self->{_menuitem_email} = Gtk2::ImageMenuItem->new($d->get('Send by E_mail...'));
 	$self->{_menuitem_email}->set_image(
 		Gtk2::Image->new_from_icon_name( 'gnome-stock-mail-snd', 'menu' )
 	);
@@ -212,7 +215,7 @@ sub fct_ret_edit_menu {
 	$self->{_menu_edit}->append( $self->{_menuitem_copy} );
 
 	$self->{_menuitem_copy_filename} = Gtk2::ImageMenuItem->new_from_stock('gtk-copy');
-	$self->{_menuitem_copy_filename}->get_child->set_text_with_mnemonic( $d->get('Copy _filename') );	
+	$self->{_menuitem_copy_filename}->get_child->set_text_with_mnemonic( $d->get('Copy _Filename') );	
 	$self->{_menuitem_copy_filename}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control><Shift>C'), qw/visible/ );
 	$self->{_menuitem_copy_filename}->set_sensitive(FALSE);
 	$self->{_menu_edit}->append( $self->{_menuitem_copy_filename} );
@@ -254,6 +257,12 @@ sub fct_ret_view_menu {
 
 	$self->{_menu_view} = Gtk2::Menu->new();
 
+	$self->{_menuitem_btoolbar} = Gtk2::CheckMenuItem->new_with_mnemonic( $d->get('Show Navigation _Toolbar') );
+	$self->{_menuitem_btoolbar}->set_active(FALSE);
+	$self->{_menu_view}->append( $self->{_menuitem_btoolbar} );
+
+	$self->{_menu_view}->append( Gtk2::SeparatorMenuItem->new );
+
 	$self->{_menuitem_zoom_in} = Gtk2::ImageMenuItem->new_from_stock('gtk-zoom-in');
 	$self->{_menuitem_zoom_in}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<control>plus'), qw/visible/ );
 	$self->{_menuitem_zoom_in}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<control>equal'), qw/visible/ );
@@ -394,19 +403,37 @@ sub fct_ret_new_menu {
 	my $icontheme = $self->{_common}->get_theme;
 
 	$self->{_menu_new} = Gtk2::Menu->new;
+
+	#redo last capture
+	$self->{_menuitem_redoshot} = Gtk2::ImageMenuItem->new_from_stock('gtk-refresh');
+	$self->{_menuitem_redoshot}->get_child->set_text_with_mnemonic( $d->get('_Redo last screenshot') );
+	$self->{_menuitem_redoshot}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('F5'), qw/visible/ );
+	$self->{_menuitem_redoshot}->set_sensitive(FALSE);
+	$self->{_menu_new}->append( $self->{_menuitem_redoshot} );
+
+	$self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
 	
 	#selection
 	$self->{_menuitem_selection} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Selection') );
-	if($icontheme->has_icon('applications-accessories')){
-		$self->{_menuitem_selection}->set_image(
-			Gtk2::Image->new_from_icon_name( 'applications-accessories', 'menu' )	
-		);
-	}else{
-		$self->{_menuitem_selection}->set_image(
-			Gtk2::Image->new_from_pixbuf(
-				Gtk2::Gdk::Pixbuf->new_from_file_at_size( "$shutter_root/share/shutter/resources/icons/selection.svg", Gtk2::IconSize->lookup('menu') )
-			)
-		);
+	
+	eval{
+		my $ccursor_pb = Gtk2::Gdk::Cursor->new('crosshair')->get_image->scale_simple(Gtk2::IconSize->lookup('menu'), 'bilinear');
+		$self->{_menuitem_selection}->set_image( 
+			Gtk2::Image->new_from_pixbuf($ccursor_pb)
+		);	
+	};
+	if($@){	
+		if($icontheme->has_icon('applications-accessories')){
+			$self->{_menuitem_selection}->set_image(
+				Gtk2::Image->new_from_icon_name( 'applications-accessories', 'menu' )	
+			);
+		}else{
+			$self->{_menuitem_selection}->set_image(
+				Gtk2::Image->new_from_pixbuf(
+					Gtk2::Gdk::Pixbuf->new_from_file_at_size( "$shutter_root/share/shutter/resources/icons/selection.svg", Gtk2::IconSize->lookup('menu') )
+				)
+			);
+		}
 	}
 	$self->{_menu_new}->append( $self->{_menuitem_selection} );
 
@@ -420,8 +447,8 @@ sub fct_ret_new_menu {
 
 	#window
 	$self->{_menuitem_window} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('W_indow') );
-	if($icontheme->has_icon('preferences-system-windows')){
-		$self->{_menuitem_window}->set_image( Gtk2::Image->new_from_icon_name( 'preferences-system-windows', 'menu' ) );	
+	if($icontheme->has_icon('gnome-window-manager')){
+		$self->{_menuitem_window}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-window-manager', 'menu' ) );	
 	}else{
 		$self->{_menuitem_window}->set_image(
 			Gtk2::Image->new_from_pixbuf(
@@ -483,8 +510,8 @@ sub fct_ret_new_menu {
 
 	#web
 	$self->{_menuitem_web} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Web') );
-	if($icontheme->has_icon('applications-internet')){
-		$self->{_menuitem_web}->set_image( Gtk2::Image->new_from_icon_name( 'applications-internet', 'menu' ) );		
+	if($icontheme->has_icon('web-browser')){
+		$self->{_menuitem_web}->set_image( Gtk2::Image->new_from_icon_name( 'web-browser', 'menu' ) );		
 	}else{
 		$self->{_menuitem_web}->set_image(
 			Gtk2::Image->new_from_pixbuf(
@@ -541,7 +568,7 @@ sub fct_ret_actions_menu{
 
 	$self->{_menu_actions}->append( Gtk2::SeparatorMenuItem->new );
 
-	$self->{_menuitem_send} = Gtk2::ImageMenuItem->new($d->get('Send To...'));
+	$self->{_menuitem_send} = Gtk2::ImageMenuItem->new($d->get('_Send To...'));
 	$self->{_menuitem_send}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>S'), qw/visible/ );
 	$self->{_menuitem_send}->set_image(
 		Gtk2::Image->new_from_icon_name( 'document-send', 'menu' )
@@ -557,6 +584,12 @@ sub fct_ret_actions_menu{
 	$self->{_menuitem_upload}->set_name('item-upload');
 	$self->{_menu_actions}->append( $self->{_menuitem_upload} );
 
+	$self->{_menuitem_links} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Public URLs') );
+	$self->{_menuitem_links}->set_image( Gtk2::Image->new_from_stock( 'gtk-network', 'menu' ) );
+	$self->{_menuitem_links}->set_sensitive(FALSE);
+	$self->{_menuitem_links}->set_name('item-links');
+	$self->{_menu_actions}->append( $self->{_menuitem_links} );
+
 	$self->{_menu_actions}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_draw} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Edit...') );
@@ -582,6 +615,15 @@ sub fct_ret_actions_menu{
 	$self->{_menuitem_plugin}->set_sensitive(FALSE);
 	$self->{_menuitem_plugin}->set_name('item-plugin');
 	$self->{_menu_actions}->append( $self->{_menuitem_plugin} );
+
+	$self->{_menu_actions}->append( Gtk2::SeparatorMenuItem->new );
+
+	$self->{_menuitem_redoshot_this} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Redo _this screenshot') );
+	$self->{_menuitem_redoshot_this}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>F5'), qw/visible/ ) if $accel_group;
+	$self->{_menuitem_redoshot_this}->set_image( Gtk2::Image->new_from_stock( 'gtk-refresh', 'menu' ) );
+	$self->{_menuitem_redoshot_this}->set_sensitive(FALSE);
+	$self->{_menuitem_redoshot_this}->set_name('item-redoshot');
+	$self->{_menu_actions}->append( $self->{_menuitem_redoshot_this} );
 	
 	$self->{_menu_actions}->show_all;
 	
@@ -622,7 +664,7 @@ sub fct_ret_actions_menu_large{
 
 	$self->{_menu_large_actions}->append( Gtk2::SeparatorMenuItem->new );
 
-	$self->{_menuitem_large_send} = Gtk2::ImageMenuItem->new($d->get('Send To...'));
+	$self->{_menuitem_large_send} = Gtk2::ImageMenuItem->new($d->get('_Send To...'));
 	$self->{_menuitem_large_send}->set_image(
 		Gtk2::Image->new_from_icon_name( 'document-send', 'menu' )
 	);
@@ -636,6 +678,12 @@ sub fct_ret_actions_menu_large{
 	$self->{_menuitem_large_upload}->set_name('item-large-upload');
 	$self->{_menu_large_actions}->append( $self->{_menuitem_large_upload} );
 
+	$self->{_menuitem_large_links} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Public URLs') );
+	$self->{_menuitem_large_links}->set_image( Gtk2::Image->new_from_stock( 'gtk-network', 'menu' ) );
+	$self->{_menuitem_large_links}->set_sensitive(FALSE);
+	$self->{_menuitem_large_links}->set_name('item-large-links');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_links} );
+
 	$self->{_menu_large_actions}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_large_copy} = Gtk2::ImageMenuItem->new_from_stock('gtk-copy');
@@ -644,7 +692,7 @@ sub fct_ret_actions_menu_large{
 	$self->{_menu_large_actions}->append( $self->{_menuitem_large_copy} );
 
 	$self->{_menuitem_large_copy_filename} = Gtk2::ImageMenuItem->new_from_stock('gtk-copy');
-	$self->{_menuitem_large_copy_filename}->get_child->set_text_with_mnemonic( $d->get('Copy _filename') );	
+	$self->{_menuitem_large_copy_filename}->get_child->set_text_with_mnemonic( $d->get('Copy _Filename') );	
 	$self->{_menuitem_large_copy_filename}->set_sensitive(FALSE);
 	$self->{_menuitem_large_copy_filename}->set_name('item-large-copy-filename');
 	$self->{_menu_large_actions}->append( $self->{_menuitem_large_copy_filename} );
@@ -673,11 +721,19 @@ sub fct_ret_actions_menu_large{
 	$self->{_menuitem_large_draw}->set_name('item-large-draw');
 	$self->{_menu_large_actions}->append( $self->{_menuitem_large_draw} );
 
-	$self->{_menuitem_large_plugin} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Run a _plugin...') );
+	$self->{_menuitem_large_plugin} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Run a _Plugin...') );
 	$self->{_menuitem_large_plugin}->set_image( Gtk2::Image->new_from_stock( 'gtk-execute', 'menu' ) );
 	$self->{_menuitem_large_plugin}->set_sensitive(FALSE);
 	$self->{_menuitem_large_plugin}->set_name('item-large-plugin');
 	$self->{_menu_large_actions}->append( $self->{_menuitem_large_plugin} );
+
+	$self->{_menu_large_actions}->append( Gtk2::SeparatorMenuItem->new );
+
+	$self->{_menuitem_large_redoshot_this} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Redo _this screenshot') );
+	$self->{_menuitem_large_redoshot_this}->set_image( Gtk2::Image->new_from_stock( 'gtk-refresh', 'menu' ) );
+	$self->{_menuitem_large_redoshot_this}->set_sensitive(FALSE);
+	$self->{_menuitem_large_redoshot_this}->set_name('item-large-redoshot');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_redoshot_this} );
 	
 	$self->{_menu_large_actions}->show_all;
 	
